import './style.css';

export class Modal {
  constructor() {
    this.modal = null;
    this.blockedEle = null;
    this.options = {};
  }

  footer() {
    const parent = document.getElementById(`my-${this.options.type}`);
    const actionEl = document.createElement('div');
    actionEl.setAttribute('id', 'btn-actions');

    if (this.options.type === 'alert') {
      actionEl.innerHTML += `<button id="submit-btn" class="btn">OK</button>`
    } else {
      actionEl.innerHTML += `
        <button id="cancel-btn" class="btn">Cancel</button>
        <button id="submit-btn" class="btn">OK</button>
      `
    }

    parent.appendChild(actionEl);

    // event listener
    this.onOk();
    this.onCancel();
  }

  onOk() {
    const okBtn = document.getElementById('submit-btn');

    if (okBtn) {
      okBtn.addEventListener('click', () => {
        if (typeof this.options.onOk === 'function') {
          if (this.options.type === 'prompt') {
            const inputVal = document.getElementById('prompt-input').value;
            this.options.onOk(inputVal);
          } else {
            this.options.onOk();
          }
        }
  
        this.close();
      })
    }
  }

  onCancel() {
    const closeBtn = document.getElementById('cancel-btn');

    if (closeBtn) {
      closeBtn.addEventListener('click', () => {
        if (typeof this.options.onCancel === 'function') {
          this.options.onCancel();
        }

        this.close();
      });
    }
  }

  alert(options) {
    this.options = { ...options };
    this.show();

    const { type = '', msg = '' } = this.options;
    const parent = document.getElementById(`my-${type}`);
    const content = document.createElement('p');

    // set message
    content.textContent = msg;
    parent.appendChild(content);

    this.footer();
  }

  confirm(options) {
    this.options = { ...options };
    this.show();

    const { type = '', msg = '' } = this.options;
    const parent = document.getElementById(`my-${type}`);
    const content = document.createElement('p');

    // set message
    content.textContent = msg;
    parent.appendChild(content);

    this.footer();
  }

  prompt(options) {
    this.options = { ...options };
    this.show();

    const { type = '', msg = '' } = this.options;
    const parent = document.getElementById(`my-${type}`);
    const input = document.createElement('input');

    // set message
    const content = document.createElement('p');
    content.textContent = msg;
    parent.appendChild(content);
    
    // set attribute for input
    input.setAttribute('id', 'prompt-input');
    input.setAttribute('type', 'text');
    parent.appendChild(input);

    // focus input
    input.focus();

    this.footer();
  }

  show() {
    if (this.modal) return;

    // create modal wrapper
    this.modal = document.createElement('div');
    this.blockedEle = document.createElement('div');

    if (this.options.type) {
      // set attribute for wrapper
      this.modal.setAttribute('id', `my-${this.options.type}`);
      this.modal.setAttribute('class', 'fixed');
      this.blockedEle.setAttribute('id', 'blocked');

      // append child
      document.body.appendChild(this.modal);
      document.body.appendChild(this.blockedEle);
    }
  }

  close() {
    const el = document.getElementById(`my-${this.options.type}`)
    const blockedEl = document.getElementById('blocked');
    blockedEl.remove();
    el.remove();
    this.options = {};
  }
}




